@@ -1,9 +1,9 @@
 package Test::Smoke::BuildCFG;
 use strict;
 
-# $Id: BuildCFG.pm 431 2003-09-22 19:33:52Z abeltje $
+# $Id: BuildCFG.pm 484 2003-10-20 05:46:22Z abeltje $
 use vars qw( $VERSION );
-$VERSION = '0.004';
+$VERSION = '0.005';
 
 use Cwd;
 use File::Spec;
@@ -344,6 +344,27 @@ sub configurations {
     @{ $self->{_list} };
 }
 
+=item $buildcfg->policy_targets( )
+
+Returns a list of policytargets from the policy substitution sections
+
+=cut
+
+sub policy_targets {
+    my $self = shift;
+
+    return unless UNIVERSAL::isa( $self->{_sections}, "ARRAY" );
+
+    my @targets;
+    for my $section ( @{ $self->{_sections} } ) { 
+        next unless UNIVERSAL::isa( $section, "HASH" ) && 
+                    $section->{policy_target};
+        push @targets, $section->{policy_target};
+    }
+
+    return @targets;
+}
+
 =item __get_smoked_configs( $logfile )
 
 Parse the logfile and return a hash(ref) of already processed
