@@ -1,9 +1,9 @@
 package TestLib;
 use strict;
 
-# $Id: TestLib.pm 468 2003-10-10 12:33:59Z abeltje $
+# $Id: TestLib.pm 475 2003-10-12 14:23:00Z abeltje $
 use vars qw( $VERSION @EXPORT );
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 use base 'Exporter';
 @EXPORT = qw( 
@@ -11,6 +11,7 @@ use base 'Exporter';
     &find_a_patch
     &find_unzip &do_unzip
     &find_untargz &do_untargz
+    &manify_path
     &get_dir &get_file &put_file
     &rmtree &mkpath
 );
@@ -62,6 +63,22 @@ sub whereis {
     return '';
 }
 
+=item manify_path( $path )
+
+Do a OS-specific split on the path, and join with '/' for MANIFEST
+format.
+
+=cut
+
+sub manify_path($) {
+    my $path = shift or return;
+    # There should be no volume on these file_paths
+    my( undef, $dirs, $file ) = File::Spec->splitpath( $path );
+    my @subdirs = grep $_ && length $_ => File::Spec->splitdir( $dirs );
+    push @subdirs, $file;
+    return join '/', @subdirs;
+}
+
 =item get_dir( $path )
 
 Returns a list of filenames (no directory-names) in C<$path>.
